# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TestRunMetricsCategorySummaryMetric(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'test_category': 'TestrunTestCategoryType',
        'category_id': 'str',
        'name': 'str',
        'value': 'float'
    }

    attribute_map = {
        'test_category': 'testCategory',
        'category_id': 'categoryId',
        'name': 'name',
        'value': 'value'
    }

    def __init__(self, test_category=None, category_id=None, name=None, value=None):  # noqa: E501
        """TestRunMetricsCategorySummaryMetric - a model defined in Swagger"""  # noqa: E501
        self._test_category = None
        self._category_id = None
        self._name = None
        self._value = None
        self.discriminator = None
        if test_category is not None:
            self.test_category = test_category
        if category_id is not None:
            self.category_id = category_id
        if name is not None:
            self.name = name
        if value is not None:
            self.value = value

    @property
    def test_category(self):
        """Gets the test_category of this TestRunMetricsCategorySummaryMetric.  # noqa: E501


        :return: The test_category of this TestRunMetricsCategorySummaryMetric.  # noqa: E501
        :rtype: TestrunTestCategoryType
        """
        return self._test_category

    @test_category.setter
    def test_category(self, test_category):
        """Sets the test_category of this TestRunMetricsCategorySummaryMetric.


        :param test_category: The test_category of this TestRunMetricsCategorySummaryMetric.  # noqa: E501
        :type: TestrunTestCategoryType
        """

        self._test_category = test_category

    @property
    def category_id(self):
        """Gets the category_id of this TestRunMetricsCategorySummaryMetric.  # noqa: E501

        The string field `category` is deprecated in v2.1 and will be removed in v2.3. Please use the enum field test_category instead, which provides the same info.  # noqa: E501

        :return: The category_id of this TestRunMetricsCategorySummaryMetric.  # noqa: E501
        :rtype: str
        """
        return self._category_id

    @category_id.setter
    def category_id(self, category_id):
        """Sets the category_id of this TestRunMetricsCategorySummaryMetric.

        The string field `category` is deprecated in v2.1 and will be removed in v2.3. Please use the enum field test_category instead, which provides the same info.  # noqa: E501

        :param category_id: The category_id of this TestRunMetricsCategorySummaryMetric.  # noqa: E501
        :type: str
        """

        self._category_id = category_id

    @property
    def name(self):
        """Gets the name of this TestRunMetricsCategorySummaryMetric.  # noqa: E501

        The name of the category.  # noqa: E501

        :return: The name of this TestRunMetricsCategorySummaryMetric.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TestRunMetricsCategorySummaryMetric.

        The name of the category.  # noqa: E501

        :param name: The name of this TestRunMetricsCategorySummaryMetric.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def value(self):
        """Gets the value of this TestRunMetricsCategorySummaryMetric.  # noqa: E501

        The value of the metric over the specified category.  # noqa: E501

        :return: The value of this TestRunMetricsCategorySummaryMetric.  # noqa: E501
        :rtype: float
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this TestRunMetricsCategorySummaryMetric.

        The value of the metric over the specified category.  # noqa: E501

        :param value: The value of this TestRunMetricsCategorySummaryMetric.  # noqa: E501
        :type: float
        """

        self._value = value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TestRunMetricsCategorySummaryMetric, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TestRunMetricsCategorySummaryMetric):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RimeCreateImageRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'pip_requirements': 'list[ManagedImagePipRequirement]',
        'package_requirements': 'list[ManagedImagePackageRequirement]',
        'python_version': 'str'
    }

    attribute_map = {
        'name': 'name',
        'pip_requirements': 'pipRequirements',
        'package_requirements': 'packageRequirements',
        'python_version': 'pythonVersion'
    }

    def __init__(self, name=None, pip_requirements=None, package_requirements=None, python_version=None):  # noqa: E501
        """RimeCreateImageRequest - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._pip_requirements = None
        self._package_requirements = None
        self._python_version = None
        self.discriminator = None
        self.name = name
        self.pip_requirements = pip_requirements
        if package_requirements is not None:
            self.package_requirements = package_requirements
        if python_version is not None:
            self.python_version = python_version

    @property
    def name(self):
        """Gets the name of this RimeCreateImageRequest.  # noqa: E501

        Name of the Managed Image.  # noqa: E501

        :return: The name of this RimeCreateImageRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this RimeCreateImageRequest.

        Name of the Managed Image.  # noqa: E501

        :param name: The name of this RimeCreateImageRequest.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def pip_requirements(self):
        """Gets the pip_requirements of this RimeCreateImageRequest.  # noqa: E501

        List of `pip` requirements that specify the customization used for this Image.  # noqa: E501

        :return: The pip_requirements of this RimeCreateImageRequest.  # noqa: E501
        :rtype: list[ManagedImagePipRequirement]
        """
        return self._pip_requirements

    @pip_requirements.setter
    def pip_requirements(self, pip_requirements):
        """Sets the pip_requirements of this RimeCreateImageRequest.

        List of `pip` requirements that specify the customization used for this Image.  # noqa: E501

        :param pip_requirements: The pip_requirements of this RimeCreateImageRequest.  # noqa: E501
        :type: list[ManagedImagePipRequirement]
        """
        if pip_requirements is None:
            raise ValueError("Invalid value for `pip_requirements`, must not be `None`")  # noqa: E501

        self._pip_requirements = pip_requirements

    @property
    def package_requirements(self):
        """Gets the package_requirements of this RimeCreateImageRequest.  # noqa: E501

        List of system requirements that specify the customization used for this Image.  # noqa: E501

        :return: The package_requirements of this RimeCreateImageRequest.  # noqa: E501
        :rtype: list[ManagedImagePackageRequirement]
        """
        return self._package_requirements

    @package_requirements.setter
    def package_requirements(self, package_requirements):
        """Sets the package_requirements of this RimeCreateImageRequest.

        List of system requirements that specify the customization used for this Image.  # noqa: E501

        :param package_requirements: The package_requirements of this RimeCreateImageRequest.  # noqa: E501
        :type: list[ManagedImagePackageRequirement]
        """

        self._package_requirements = package_requirements

    @property
    def python_version(self):
        """Gets the python_version of this RimeCreateImageRequest.  # noqa: E501

        The version of the Python interpreter to use.  # noqa: E501

        :return: The python_version of this RimeCreateImageRequest.  # noqa: E501
        :rtype: str
        """
        return self._python_version

    @python_version.setter
    def python_version(self, python_version):
        """Sets the python_version of this RimeCreateImageRequest.

        The version of the Python interpreter to use.  # noqa: E501

        :param python_version: The python_version of this RimeCreateImageRequest.  # noqa: E501
        :type: str
        """

        self._python_version = python_version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RimeCreateImageRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RimeCreateImageRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ProjectProjectWithDetails(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'project': 'ProjectProject',
        'owner_details': 'ProjectOwnerDetails',
        'last_updated_time': 'datetime'
    }

    attribute_map = {
        'project': 'project',
        'owner_details': 'ownerDetails',
        'last_updated_time': 'lastUpdatedTime'
    }

    def __init__(self, project=None, owner_details=None, last_updated_time=None):  # noqa: E501
        """ProjectProjectWithDetails - a model defined in Swagger"""  # noqa: E501
        self._project = None
        self._owner_details = None
        self._last_updated_time = None
        self.discriminator = None
        if project is not None:
            self.project = project
        if owner_details is not None:
            self.owner_details = owner_details
        if last_updated_time is not None:
            self.last_updated_time = last_updated_time

    @property
    def project(self):
        """Gets the project of this ProjectProjectWithDetails.  # noqa: E501


        :return: The project of this ProjectProjectWithDetails.  # noqa: E501
        :rtype: ProjectProject
        """
        return self._project

    @project.setter
    def project(self, project):
        """Sets the project of this ProjectProjectWithDetails.


        :param project: The project of this ProjectProjectWithDetails.  # noqa: E501
        :type: ProjectProject
        """

        self._project = project

    @property
    def owner_details(self):
        """Gets the owner_details of this ProjectProjectWithDetails.  # noqa: E501


        :return: The owner_details of this ProjectProjectWithDetails.  # noqa: E501
        :rtype: ProjectOwnerDetails
        """
        return self._owner_details

    @owner_details.setter
    def owner_details(self, owner_details):
        """Sets the owner_details of this ProjectProjectWithDetails.


        :param owner_details: The owner_details of this ProjectProjectWithDetails.  # noqa: E501
        :type: ProjectOwnerDetails
        """

        self._owner_details = owner_details

    @property
    def last_updated_time(self):
        """Gets the last_updated_time of this ProjectProjectWithDetails.  # noqa: E501


        :return: The last_updated_time of this ProjectProjectWithDetails.  # noqa: E501
        :rtype: datetime
        """
        return self._last_updated_time

    @last_updated_time.setter
    def last_updated_time(self, last_updated_time):
        """Sets the last_updated_time of this ProjectProjectWithDetails.


        :param last_updated_time: The last_updated_time of this ProjectProjectWithDetails.  # noqa: E501
        :type: datetime
        """

        self._last_updated_time = last_updated_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ProjectProjectWithDetails, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProjectProjectWithDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RegistryHuggingFaceModelInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'model_uri': 'str',
        'kwargs': 'str'
    }

    attribute_map = {
        'model_uri': 'modelUri',
        'kwargs': 'kwargs'
    }

    def __init__(self, model_uri=None, kwargs=None):  # noqa: E501
        """RegistryHuggingFaceModelInfo - a model defined in Swagger"""  # noqa: E501
        self._model_uri = None
        self._kwargs = None
        self.discriminator = None
        if model_uri is not None:
            self.model_uri = model_uri
        if kwargs is not None:
            self.kwargs = kwargs

    @property
    def model_uri(self):
        """Gets the model_uri of this RegistryHuggingFaceModelInfo.  # noqa: E501


        :return: The model_uri of this RegistryHuggingFaceModelInfo.  # noqa: E501
        :rtype: str
        """
        return self._model_uri

    @model_uri.setter
    def model_uri(self, model_uri):
        """Sets the model_uri of this RegistryHuggingFaceModelInfo.


        :param model_uri: The model_uri of this RegistryHuggingFaceModelInfo.  # noqa: E501
        :type: str
        """

        self._model_uri = model_uri

    @property
    def kwargs(self):
        """Gets the kwargs of this RegistryHuggingFaceModelInfo.  # noqa: E501

        We are currently in the process of adding extra huggingface params and separating use cases into tabular and nlp. Use a serialized json dictionary for other variables right now to ensure maximum flexibility.  # noqa: E501

        :return: The kwargs of this RegistryHuggingFaceModelInfo.  # noqa: E501
        :rtype: str
        """
        return self._kwargs

    @kwargs.setter
    def kwargs(self, kwargs):
        """Sets the kwargs of this RegistryHuggingFaceModelInfo.

        We are currently in the process of adding extra huggingface params and separating use cases into tabular and nlp. Use a serialized json dictionary for other variables right now to ensure maximum flexibility.  # noqa: E501

        :param kwargs: The kwargs of this RegistryHuggingFaceModelInfo.  # noqa: E501
        :type: str
        """

        self._kwargs = kwargs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RegistryHuggingFaceModelInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RegistryHuggingFaceModelInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class DataProfilingColumnTypeInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'min_nunique_for_numeric': 'str',
        'numeric_violation_threshold': 'float',
        'categorical_violation_threshold': 'float',
        'min_unique_prop': 'float',
        'allow_float_unique': 'bool',
        'numeric_range_inference_threshold': 'float',
        'unseen_values_allowed_criteria': 'float'
    }

    attribute_map = {
        'min_nunique_for_numeric': 'minNuniqueForNumeric',
        'numeric_violation_threshold': 'numericViolationThreshold',
        'categorical_violation_threshold': 'categoricalViolationThreshold',
        'min_unique_prop': 'minUniqueProp',
        'allow_float_unique': 'allowFloatUnique',
        'numeric_range_inference_threshold': 'numericRangeInferenceThreshold',
        'unseen_values_allowed_criteria': 'unseenValuesAllowedCriteria'
    }

    def __init__(self, min_nunique_for_numeric=None, numeric_violation_threshold=None, categorical_violation_threshold=None, min_unique_prop=None, allow_float_unique=None, numeric_range_inference_threshold=None, unseen_values_allowed_criteria=None):  # noqa: E501
        """DataProfilingColumnTypeInfo - a model defined in Swagger"""  # noqa: E501
        self._min_nunique_for_numeric = None
        self._numeric_violation_threshold = None
        self._categorical_violation_threshold = None
        self._min_unique_prop = None
        self._allow_float_unique = None
        self._numeric_range_inference_threshold = None
        self._unseen_values_allowed_criteria = None
        self.discriminator = None
        if min_nunique_for_numeric is not None:
            self.min_nunique_for_numeric = min_nunique_for_numeric
        if numeric_violation_threshold is not None:
            self.numeric_violation_threshold = numeric_violation_threshold
        if categorical_violation_threshold is not None:
            self.categorical_violation_threshold = categorical_violation_threshold
        if min_unique_prop is not None:
            self.min_unique_prop = min_unique_prop
        if allow_float_unique is not None:
            self.allow_float_unique = allow_float_unique
        if numeric_range_inference_threshold is not None:
            self.numeric_range_inference_threshold = numeric_range_inference_threshold
        if unseen_values_allowed_criteria is not None:
            self.unseen_values_allowed_criteria = unseen_values_allowed_criteria

    @property
    def min_nunique_for_numeric(self):
        """Gets the min_nunique_for_numeric of this DataProfilingColumnTypeInfo.  # noqa: E501

        Specifies a minimum number of unique values in a column. Columns with at least the specified number of unique values are considered numeric columns. Columns with fewer unique values are considered categorical.  # noqa: E501

        :return: The min_nunique_for_numeric of this DataProfilingColumnTypeInfo.  # noqa: E501
        :rtype: str
        """
        return self._min_nunique_for_numeric

    @min_nunique_for_numeric.setter
    def min_nunique_for_numeric(self, min_nunique_for_numeric):
        """Sets the min_nunique_for_numeric of this DataProfilingColumnTypeInfo.

        Specifies a minimum number of unique values in a column. Columns with at least the specified number of unique values are considered numeric columns. Columns with fewer unique values are considered categorical.  # noqa: E501

        :param min_nunique_for_numeric: The min_nunique_for_numeric of this DataProfilingColumnTypeInfo.  # noqa: E501
        :type: str
        """

        self._min_nunique_for_numeric = min_nunique_for_numeric

    @property
    def numeric_violation_threshold(self):
        """Gets the numeric_violation_threshold of this DataProfilingColumnTypeInfo.  # noqa: E501

        Maximum fraction of violations when assigning numeric columns (not including missing values).  # noqa: E501

        :return: The numeric_violation_threshold of this DataProfilingColumnTypeInfo.  # noqa: E501
        :rtype: float
        """
        return self._numeric_violation_threshold

    @numeric_violation_threshold.setter
    def numeric_violation_threshold(self, numeric_violation_threshold):
        """Sets the numeric_violation_threshold of this DataProfilingColumnTypeInfo.

        Maximum fraction of violations when assigning numeric columns (not including missing values).  # noqa: E501

        :param numeric_violation_threshold: The numeric_violation_threshold of this DataProfilingColumnTypeInfo.  # noqa: E501
        :type: float
        """

        self._numeric_violation_threshold = numeric_violation_threshold

    @property
    def categorical_violation_threshold(self):
        """Gets the categorical_violation_threshold of this DataProfilingColumnTypeInfo.  # noqa: E501

        Maximum fraction of violations when assigning categorical subtypes (not including missing values).  # noqa: E501

        :return: The categorical_violation_threshold of this DataProfilingColumnTypeInfo.  # noqa: E501
        :rtype: float
        """
        return self._categorical_violation_threshold

    @categorical_violation_threshold.setter
    def categorical_violation_threshold(self, categorical_violation_threshold):
        """Sets the categorical_violation_threshold of this DataProfilingColumnTypeInfo.

        Maximum fraction of violations when assigning categorical subtypes (not including missing values).  # noqa: E501

        :param categorical_violation_threshold: The categorical_violation_threshold of this DataProfilingColumnTypeInfo.  # noqa: E501
        :type: float
        """

        self._categorical_violation_threshold = categorical_violation_threshold

    @property
    def min_unique_prop(self):
        """Gets the min_unique_prop of this DataProfilingColumnTypeInfo.  # noqa: E501

        If data has at least min_unique_prop proportion of unique values then classify as a column that must have unique values.  # noqa: E501

        :return: The min_unique_prop of this DataProfilingColumnTypeInfo.  # noqa: E501
        :rtype: float
        """
        return self._min_unique_prop

    @min_unique_prop.setter
    def min_unique_prop(self, min_unique_prop):
        """Sets the min_unique_prop of this DataProfilingColumnTypeInfo.

        If data has at least min_unique_prop proportion of unique values then classify as a column that must have unique values.  # noqa: E501

        :param min_unique_prop: The min_unique_prop of this DataProfilingColumnTypeInfo.  # noqa: E501
        :type: float
        """

        self._min_unique_prop = min_unique_prop

    @property
    def allow_float_unique(self):
        """Gets the allow_float_unique of this DataProfilingColumnTypeInfo.  # noqa: E501

        Allow float columns to be inferred as unique values.  # noqa: E501

        :return: The allow_float_unique of this DataProfilingColumnTypeInfo.  # noqa: E501
        :rtype: bool
        """
        return self._allow_float_unique

    @allow_float_unique.setter
    def allow_float_unique(self, allow_float_unique):
        """Sets the allow_float_unique of this DataProfilingColumnTypeInfo.

        Allow float columns to be inferred as unique values.  # noqa: E501

        :param allow_float_unique: The allow_float_unique of this DataProfilingColumnTypeInfo.  # noqa: E501
        :type: bool
        """

        self._allow_float_unique = allow_float_unique

    @property
    def numeric_range_inference_threshold(self):
        """Gets the numeric_range_inference_threshold of this DataProfilingColumnTypeInfo.  # noqa: E501

        The percent of non-null values which must fall within an inferrable numeric range ([0,1], [0,inf), (-inf, inf)) for that to be inferred as the valid range for a numeric column. If 1.0 (default), then all non-null values must fall within the range for that range to be inferred. For ex: if 98% of feature X falls in [0, 1] but 100% of feature X falls in [0, inf) then we'll infer [0, inf) as the valid range for feature X. However, if this threshold is 0.98, we'll instead infer [0, 1] as feature X's range.  # noqa: E501

        :return: The numeric_range_inference_threshold of this DataProfilingColumnTypeInfo.  # noqa: E501
        :rtype: float
        """
        return self._numeric_range_inference_threshold

    @numeric_range_inference_threshold.setter
    def numeric_range_inference_threshold(self, numeric_range_inference_threshold):
        """Sets the numeric_range_inference_threshold of this DataProfilingColumnTypeInfo.

        The percent of non-null values which must fall within an inferrable numeric range ([0,1], [0,inf), (-inf, inf)) for that to be inferred as the valid range for a numeric column. If 1.0 (default), then all non-null values must fall within the range for that range to be inferred. For ex: if 98% of feature X falls in [0, 1] but 100% of feature X falls in [0, inf) then we'll infer [0, inf) as the valid range for feature X. However, if this threshold is 0.98, we'll instead infer [0, 1] as feature X's range.  # noqa: E501

        :param numeric_range_inference_threshold: The numeric_range_inference_threshold of this DataProfilingColumnTypeInfo.  # noqa: E501
        :type: float
        """

        self._numeric_range_inference_threshold = numeric_range_inference_threshold

    @property
    def unseen_values_allowed_criteria(self):
        """Gets the unseen_values_allowed_criteria of this DataProfilingColumnTypeInfo.  # noqa: E501

        Either the fraction or count of unique values in the ref set required to infer that a categorical feature is allowed to have unseen values in the eval set. If the criteria is provided as a float in [0.0, 1.0] it will be treated as the fraction of unique non-null values divided by the total number of non-null values required to infer that unseen values are allowed. If provided as an integer in [2, inf), it will be treated as the count of non-null unique values required to infer that unseen values are allowed.  # noqa: E501

        :return: The unseen_values_allowed_criteria of this DataProfilingColumnTypeInfo.  # noqa: E501
        :rtype: float
        """
        return self._unseen_values_allowed_criteria

    @unseen_values_allowed_criteria.setter
    def unseen_values_allowed_criteria(self, unseen_values_allowed_criteria):
        """Sets the unseen_values_allowed_criteria of this DataProfilingColumnTypeInfo.

        Either the fraction or count of unique values in the ref set required to infer that a categorical feature is allowed to have unseen values in the eval set. If the criteria is provided as a float in [0.0, 1.0] it will be treated as the fraction of unique non-null values divided by the total number of non-null values required to infer that unseen values are allowed. If provided as an integer in [2, inf), it will be treated as the count of non-null unique values required to infer that unseen values are allowed.  # noqa: E501

        :param unseen_values_allowed_criteria: The unseen_values_allowed_criteria of this DataProfilingColumnTypeInfo.  # noqa: E501
        :type: float
        """

        self._unseen_values_allowed_criteria = unseen_values_allowed_criteria

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DataProfilingColumnTypeInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DataProfilingColumnTypeInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



"""General Utilities."""
from html import escape
from typing import Any, Dict, List, Optional, Sequence

from google.protobuf.field_mask_pb2 import FieldMask
from google.protobuf.json_format import MessageToDict

HEADER_TMPL = "<th>{0}</th>"
DATA_TMPL = "<td>{0}</td>"
ROW_TMPL = "<tr>{0}</tr>"
TABLE_TMPL = '<table style="width:100%">{0}</table>'


def make_link(link: str, link_text: Optional[str] = None) -> str:
    """Make the HTML link."""
    if not link_text:
        link_text = "Link"
    return f'<a href="{link}" target="_blank" rel="noopener">{escape(link_text)}</a>'


def get_header_row_string(column_headers: Sequence[str]) -> str:
    """Return the table header row as a sring."""
    headers = [HEADER_TMPL.format(header) for header in column_headers]
    return ROW_TMPL.format("".join(headers))


def get_data_row_string(data_values: Sequence[str]) -> str:
    """Return a table data row as a string."""
    data = [DATA_TMPL.format(datum) for datum in data_values]
    return ROW_TMPL.format("".join(data))


def convert_dict_to_html(table_dict: Dict[str, str]) -> str:
    """Convert a dictionary to an HTML table."""
    if len(table_dict) == 0:
        return ""

    all_rows = [
        get_header_row_string(list(table_dict)),
        get_data_row_string(list(table_dict.values())),
    ]
    return TABLE_TMPL.format("".join(all_rows))


def assert_and_get_none_or_all_none(*args: Optional[Any]) -> bool:
    """Check that all arguments are None or all are not None.

    Args:
        *args: Arguments to check.

    Returns:
        True if all arguments are not None, False if all are None.

    Raises:
        ValueError
            When some arguments are None and some are not.
    """
    if all(arg is None for arg in args):
        return False
    elif all(arg is not None for arg in args):
        return True
    else:
        raise ValueError(f"All arguments {args} must be None or all must be not None.")


def _get_field_mask_paths(v: Any, path_elements: List[str]) -> List[str]:
    """Get the field mask paths for a swagger object where the values are non-null."""
    if v is None:
        return []
    if not isinstance(v, dict):
        return [".".join(path_elements)]
    mask_paths = []
    for key, val in v.items():
        mask_paths += _get_field_mask_paths(val, path_elements + [key])
    return mask_paths


def get_swagger_field_mask(swagger_object: Any) -> dict:
    """Get a field mask for a swagger object that recursively masks non-null fields."""
    mask_paths = _get_field_mask_paths(swagger_object.to_dict(), [])
    mask = FieldMask(paths=mask_paths)
    serialized_mask = MessageToDict(mask)
    return serialized_mask



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RimeListJobsForProjectRequestQuery(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'selected_statuses': 'list[StatedbJobStatus]',
        'selected_types': 'list[RimeJobType]'
    }

    attribute_map = {
        'selected_statuses': 'selectedStatuses',
        'selected_types': 'selectedTypes'
    }

    def __init__(self, selected_statuses=None, selected_types=None):  # noqa: E501
        """RimeListJobsForProjectRequestQuery - a model defined in Swagger"""  # noqa: E501
        self._selected_statuses = None
        self._selected_types = None
        self.discriminator = None
        if selected_statuses is not None:
            self.selected_statuses = selected_statuses
        if selected_types is not None:
            self.selected_types = selected_types

    @property
    def selected_statuses(self):
        """Gets the selected_statuses of this RimeListJobsForProjectRequestQuery.  # noqa: E501

        Specifies a set of statuses. The query only returns results with a status in the specified set. Specify no statuses to return all results.  # noqa: E501

        :return: The selected_statuses of this RimeListJobsForProjectRequestQuery.  # noqa: E501
        :rtype: list[StatedbJobStatus]
        """
        return self._selected_statuses

    @selected_statuses.setter
    def selected_statuses(self, selected_statuses):
        """Sets the selected_statuses of this RimeListJobsForProjectRequestQuery.

        Specifies a set of statuses. The query only returns results with a status in the specified set. Specify no statuses to return all results.  # noqa: E501

        :param selected_statuses: The selected_statuses of this RimeListJobsForProjectRequestQuery.  # noqa: E501
        :type: list[StatedbJobStatus]
        """

        self._selected_statuses = selected_statuses

    @property
    def selected_types(self):
        """Gets the selected_types of this RimeListJobsForProjectRequestQuery.  # noqa: E501

        Specifies a set of types. The query only returns jobs with types in the specified set. Specify no types to return all results. Job types not tied to projects will not be returned.  # noqa: E501

        :return: The selected_types of this RimeListJobsForProjectRequestQuery.  # noqa: E501
        :rtype: list[RimeJobType]
        """
        return self._selected_types

    @selected_types.setter
    def selected_types(self, selected_types):
        """Sets the selected_types of this RimeListJobsForProjectRequestQuery.

        Specifies a set of types. The query only returns jobs with types in the specified set. Specify no types to return all results. Job types not tied to projects will not be returned.  # noqa: E501

        :param selected_types: The selected_types of this RimeListJobsForProjectRequestQuery.  # noqa: E501
        :type: list[RimeJobType]
        """

        self._selected_types = selected_types

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RimeListJobsForProjectRequestQuery, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RimeListJobsForProjectRequestQuery):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from rime_sdk.swagger.swagger_client.api_client import ApiClient


class UserApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def user_create_api_token(self, body, **kwargs):  # noqa: E501
        """CreateAPIToken  # noqa: E501

        Create a new API token.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_create_api_token(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RimeCreateAPITokenRequest body: (required)
        :return: RimeCreateAPITokenResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.user_create_api_token_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.user_create_api_token_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def user_create_api_token_with_http_info(self, body, **kwargs):  # noqa: E501
        """CreateAPIToken  # noqa: E501

        Create a new API token.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_create_api_token_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RimeCreateAPITokenRequest body: (required)
        :return: RimeCreateAPITokenResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method user_create_api_token" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `user_create_api_token`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/users/api-tokens', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeCreateAPITokenResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def user_create_user(self, body, **kwargs):  # noqa: E501
        """CreateUser  # noqa: E501

        Creates a user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_create_user(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RimeCreateUserRequest body: (required)
        :return: RimeCreateUserResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.user_create_user_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.user_create_user_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def user_create_user_with_http_info(self, body, **kwargs):  # noqa: E501
        """CreateUser  # noqa: E501

        Creates a user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_create_user_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RimeCreateUserRequest body: (required)
        :return: RimeCreateUserResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method user_create_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `user_create_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/users', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeCreateUserResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def user_delete_api_token(self, id_uuid, **kwargs):  # noqa: E501
        """DeleteAPIToken  # noqa: E501

        Delete an API token by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_delete_api_token(id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id_uuid: Unique object ID. (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.user_delete_api_token_with_http_info(id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.user_delete_api_token_with_http_info(id_uuid, **kwargs)  # noqa: E501
            return data

    def user_delete_api_token_with_http_info(self, id_uuid, **kwargs):  # noqa: E501
        """DeleteAPIToken  # noqa: E501

        Delete an API token by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_delete_api_token_with_http_info(id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id_uuid: Unique object ID. (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method user_delete_api_token" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id_uuid' is set
        if ('id_uuid' not in params or
                params['id_uuid'] is None):
            raise ValueError("Missing the required parameter `id_uuid` when calling `user_delete_api_token`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id_uuid' in params:
            path_params['id.uuid'] = params['id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/users/api-tokens/{id.uuid}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def user_delete_user(self, user_id_uuid, **kwargs):  # noqa: E501
        """DeleteUser  # noqa: E501

        Delete the user with the specified ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_delete_user(user_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id_uuid: Unique object ID. (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.user_delete_user_with_http_info(user_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.user_delete_user_with_http_info(user_id_uuid, **kwargs)  # noqa: E501
            return data

    def user_delete_user_with_http_info(self, user_id_uuid, **kwargs):  # noqa: E501
        """DeleteUser  # noqa: E501

        Delete the user with the specified ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_delete_user_with_http_info(user_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id_uuid: Unique object ID. (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method user_delete_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id_uuid' is set
        if ('user_id_uuid' not in params or
                params['user_id_uuid'] is None):
            raise ValueError("Missing the required parameter `user_id_uuid` when calling `user_delete_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id_uuid' in params:
            path_params['userId.uuid'] = params['user_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/users/{userId.uuid}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def user_get_user(self, user_id_uuid, **kwargs):  # noqa: E501
        """GetUser  # noqa: E501

        Return the user with the specified ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_get_user(user_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id_uuid: Unique object ID. (required)
        :param str oidc_id_token: ID of the OIDC provider token.
        :return: RimeGetUserResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.user_get_user_with_http_info(user_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.user_get_user_with_http_info(user_id_uuid, **kwargs)  # noqa: E501
            return data

    def user_get_user_with_http_info(self, user_id_uuid, **kwargs):  # noqa: E501
        """GetUser  # noqa: E501

        Return the user with the specified ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_get_user_with_http_info(user_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id_uuid: Unique object ID. (required)
        :param str oidc_id_token: ID of the OIDC provider token.
        :return: RimeGetUserResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id_uuid', 'oidc_id_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method user_get_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id_uuid' is set
        if ('user_id_uuid' not in params or
                params['user_id_uuid'] is None):
            raise ValueError("Missing the required parameter `user_id_uuid` when calling `user_get_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id_uuid' in params:
            path_params['userId.uuid'] = params['user_id_uuid']  # noqa: E501

        query_params = []
        if 'oidc_id_token' in params:
            query_params.append(('oidcIdToken', params['oidc_id_token']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/users/{userId.uuid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeGetUserResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def user_list_api_tokens(self, **kwargs):  # noqa: E501
        """ListAPITokens  # noqa: E501

        List all API tokens for a Workspace.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_list_api_tokens(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str page_token: Specifies a page of the list returned by a ListAPITokens query. The ListAPITokens query returns a pageToken when there is more than one page of results.
        :param str page_size: The maximum number of API Token objects to return in a single page.
        :param str workspace_id_uuid: Unique object ID.
        :return: RimeListAPITokensResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.user_list_api_tokens_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.user_list_api_tokens_with_http_info(**kwargs)  # noqa: E501
            return data

    def user_list_api_tokens_with_http_info(self, **kwargs):  # noqa: E501
        """ListAPITokens  # noqa: E501

        List all API tokens for a Workspace.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_list_api_tokens_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str page_token: Specifies a page of the list returned by a ListAPITokens query. The ListAPITokens query returns a pageToken when there is more than one page of results.
        :param str page_size: The maximum number of API Token objects to return in a single page.
        :param str workspace_id_uuid: Unique object ID.
        :return: RimeListAPITokensResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page_token', 'page_size', 'workspace_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method user_list_api_tokens" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page_token' in params:
            query_params.append(('pageToken', params['page_token']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501
        if 'workspace_id_uuid' in params:
            query_params.append(('workspaceId.uuid', params['workspace_id_uuid']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/users/api-tokens', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeListAPITokensResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def user_list_current_user_roles(self, **kwargs):  # noqa: E501
        """ListCurrentUserRoles  # noqa: E501

        Returns the list of roles of the logged in user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_list_current_user_roles(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: RimeListCurrentUserRolesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.user_list_current_user_roles_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.user_list_current_user_roles_with_http_info(**kwargs)  # noqa: E501
            return data

    def user_list_current_user_roles_with_http_info(self, **kwargs):  # noqa: E501
        """ListCurrentUserRoles  # noqa: E501

        Returns the list of roles of the logged in user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_list_current_user_roles_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: RimeListCurrentUserRolesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method user_list_current_user_roles" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/users/roles', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeListCurrentUserRolesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def user_list_users(self, **kwargs):  # noqa: E501
        """ListUsers  # noqa: E501

        List all users.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_list_users(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str page_token: Specifies a page of the list returned by a ListUsers query. The ListUsers query returns a pageToken when there is more than one page of results. Specify either this field or the firstPageQuery field.
        :param str page_size: The maximum number of User objects to return in a single page.
        :return: RimeListUsersResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.user_list_users_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.user_list_users_with_http_info(**kwargs)  # noqa: E501
            return data

    def user_list_users_with_http_info(self, **kwargs):  # noqa: E501
        """ListUsers  # noqa: E501

        List all users.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_list_users_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str page_token: Specifies a page of the list returned by a ListUsers query. The ListUsers query returns a pageToken when there is more than one page of results. Specify either this field or the firstPageQuery field.
        :param str page_size: The maximum number of User objects to return in a single page.
        :return: RimeListUsersResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page_token', 'page_size']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method user_list_users" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page_token' in params:
            query_params.append(('pageToken', params['page_token']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/users', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeListUsersResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def user_reset_password(self, body, user_id_uuid, **kwargs):  # noqa: E501
        """ResetPassword  # noqa: E501

        Reset the password of a user with the specified ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_reset_password(body, user_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ResetpasswordUserIdUuidBody body: (required)
        :param str user_id_uuid: Unique object ID. (required)
        :return: RimeResetPasswordResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.user_reset_password_with_http_info(body, user_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.user_reset_password_with_http_info(body, user_id_uuid, **kwargs)  # noqa: E501
            return data

    def user_reset_password_with_http_info(self, body, user_id_uuid, **kwargs):  # noqa: E501
        """ResetPassword  # noqa: E501

        Reset the password of a user with the specified ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_reset_password_with_http_info(body, user_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ResetpasswordUserIdUuidBody body: (required)
        :param str user_id_uuid: Unique object ID. (required)
        :return: RimeResetPasswordResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'user_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method user_reset_password" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `user_reset_password`")  # noqa: E501
        # verify the required parameter 'user_id_uuid' is set
        if ('user_id_uuid' not in params or
                params['user_id_uuid'] is None):
            raise ValueError("Missing the required parameter `user_id_uuid` when calling `user_reset_password`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id_uuid' in params:
            path_params['userId.uuid'] = params['user_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/users/reset-password/{userId.uuid}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeResetPasswordResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def user_update_user(self, body, user_id_uuid, **kwargs):  # noqa: E501
        """UpdateUser  # noqa: E501

        Update a user with the specified ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_update_user(body, user_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UsersUserIdUuidBody body: (required)
        :param str user_id_uuid: Unique object ID. (required)
        :return: RimeUpdateUserResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.user_update_user_with_http_info(body, user_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.user_update_user_with_http_info(body, user_id_uuid, **kwargs)  # noqa: E501
            return data

    def user_update_user_with_http_info(self, body, user_id_uuid, **kwargs):  # noqa: E501
        """UpdateUser  # noqa: E501

        Update a user with the specified ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_update_user_with_http_info(body, user_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UsersUserIdUuidBody body: (required)
        :param str user_id_uuid: Unique object ID. (required)
        :return: RimeUpdateUserResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'user_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method user_update_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `user_update_user`")  # noqa: E501
        # verify the required parameter 'user_id_uuid' is set
        if ('user_id_uuid' not in params or
                params['user_id_uuid'] is None):
            raise ValueError("Missing the required parameter `user_id_uuid` when calling `user_update_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id_uuid' in params:
            path_params['user.id.uuid'] = params['user_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/users/{user.id.uuid}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeUpdateUserResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RegistryDataParams(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'label_col': 'str',
        'timestamp_col': 'str',
        'class_names': 'list[str]',
        'ranking_info': 'DataParamsRankingInfo',
        'nrows': 'str',
        'nrows_per_time_bin': 'str',
        'sample': 'bool',
        'categorical_features': 'list[str]',
        'protected_features': 'list[str]',
        'features_not_in_model': 'list[str]',
        'text_features': 'list[str]',
        'image_features': 'list[str]',
        'prompt_col': 'str',
        'intersections': 'list[DataParamsFeatureIntersection]',
        'loading_kwargs': 'str',
        'feature_type_path': 'str',
        'image_load_path': 'str',
        'experimental_fields': 'dict(str, object)'
    }

    attribute_map = {
        'label_col': 'labelCol',
        'timestamp_col': 'timestampCol',
        'class_names': 'classNames',
        'ranking_info': 'rankingInfo',
        'nrows': 'nrows',
        'nrows_per_time_bin': 'nrowsPerTimeBin',
        'sample': 'sample',
        'categorical_features': 'categoricalFeatures',
        'protected_features': 'protectedFeatures',
        'features_not_in_model': 'featuresNotInModel',
        'text_features': 'textFeatures',
        'image_features': 'imageFeatures',
        'prompt_col': 'promptCol',
        'intersections': 'intersections',
        'loading_kwargs': 'loadingKwargs',
        'feature_type_path': 'featureTypePath',
        'image_load_path': 'imageLoadPath',
        'experimental_fields': 'experimentalFields'
    }

    def __init__(self, label_col=None, timestamp_col=None, class_names=None, ranking_info=None, nrows=None, nrows_per_time_bin=None, sample=None, categorical_features=None, protected_features=None, features_not_in_model=None, text_features=None, image_features=None, prompt_col=None, intersections=None, loading_kwargs=None, feature_type_path=None, image_load_path=None, experimental_fields=None):  # noqa: E501
        """RegistryDataParams - a model defined in Swagger"""  # noqa: E501
        self._label_col = None
        self._timestamp_col = None
        self._class_names = None
        self._ranking_info = None
        self._nrows = None
        self._nrows_per_time_bin = None
        self._sample = None
        self._categorical_features = None
        self._protected_features = None
        self._features_not_in_model = None
        self._text_features = None
        self._image_features = None
        self._prompt_col = None
        self._intersections = None
        self._loading_kwargs = None
        self._feature_type_path = None
        self._image_load_path = None
        self._experimental_fields = None
        self.discriminator = None
        if label_col is not None:
            self.label_col = label_col
        if timestamp_col is not None:
            self.timestamp_col = timestamp_col
        if class_names is not None:
            self.class_names = class_names
        if ranking_info is not None:
            self.ranking_info = ranking_info
        if nrows is not None:
            self.nrows = nrows
        if nrows_per_time_bin is not None:
            self.nrows_per_time_bin = nrows_per_time_bin
        if sample is not None:
            self.sample = sample
        if categorical_features is not None:
            self.categorical_features = categorical_features
        if protected_features is not None:
            self.protected_features = protected_features
        if features_not_in_model is not None:
            self.features_not_in_model = features_not_in_model
        if text_features is not None:
            self.text_features = text_features
        if image_features is not None:
            self.image_features = image_features
        if prompt_col is not None:
            self.prompt_col = prompt_col
        if intersections is not None:
            self.intersections = intersections
        if loading_kwargs is not None:
            self.loading_kwargs = loading_kwargs
        if feature_type_path is not None:
            self.feature_type_path = feature_type_path
        if image_load_path is not None:
            self.image_load_path = image_load_path
        if experimental_fields is not None:
            self.experimental_fields = experimental_fields

    @property
    def label_col(self):
        """Gets the label_col of this RegistryDataParams.  # noqa: E501

        Naming of special columns.  # noqa: E501

        :return: The label_col of this RegistryDataParams.  # noqa: E501
        :rtype: str
        """
        return self._label_col

    @label_col.setter
    def label_col(self, label_col):
        """Sets the label_col of this RegistryDataParams.

        Naming of special columns.  # noqa: E501

        :param label_col: The label_col of this RegistryDataParams.  # noqa: E501
        :type: str
        """

        self._label_col = label_col

    @property
    def timestamp_col(self):
        """Gets the timestamp_col of this RegistryDataParams.  # noqa: E501

        Column to look at for CT timestamp.  # noqa: E501

        :return: The timestamp_col of this RegistryDataParams.  # noqa: E501
        :rtype: str
        """
        return self._timestamp_col

    @timestamp_col.setter
    def timestamp_col(self, timestamp_col):
        """Sets the timestamp_col of this RegistryDataParams.

        Column to look at for CT timestamp.  # noqa: E501

        :param timestamp_col: The timestamp_col of this RegistryDataParams.  # noqa: E501
        :type: str
        """

        self._timestamp_col = timestamp_col

    @property
    def class_names(self):
        """Gets the class_names of this RegistryDataParams.  # noqa: E501

        List of label class names.  # noqa: E501

        :return: The class_names of this RegistryDataParams.  # noqa: E501
        :rtype: list[str]
        """
        return self._class_names

    @class_names.setter
    def class_names(self, class_names):
        """Sets the class_names of this RegistryDataParams.

        List of label class names.  # noqa: E501

        :param class_names: The class_names of this RegistryDataParams.  # noqa: E501
        :type: list[str]
        """

        self._class_names = class_names

    @property
    def ranking_info(self):
        """Gets the ranking_info of this RegistryDataParams.  # noqa: E501


        :return: The ranking_info of this RegistryDataParams.  # noqa: E501
        :rtype: DataParamsRankingInfo
        """
        return self._ranking_info

    @ranking_info.setter
    def ranking_info(self, ranking_info):
        """Sets the ranking_info of this RegistryDataParams.


        :param ranking_info: The ranking_info of this RegistryDataParams.  # noqa: E501
        :type: DataParamsRankingInfo
        """

        self._ranking_info = ranking_info

    @property
    def nrows(self):
        """Gets the nrows of this RegistryDataParams.  # noqa: E501

        Dataset size parameters. Number of rows of data to load and test. If null, will load all rows.  # noqa: E501

        :return: The nrows of this RegistryDataParams.  # noqa: E501
        :rtype: str
        """
        return self._nrows

    @nrows.setter
    def nrows(self, nrows):
        """Sets the nrows of this RegistryDataParams.

        Dataset size parameters. Number of rows of data to load and test. If null, will load all rows.  # noqa: E501

        :param nrows: The nrows of this RegistryDataParams.  # noqa: E501
        :type: str
        """

        self._nrows = nrows

    @property
    def nrows_per_time_bin(self):
        """Gets the nrows_per_time_bin of this RegistryDataParams.  # noqa: E501

        Number of rows of data per time bin to load and test in CT. If null, will load all rows.  # noqa: E501

        :return: The nrows_per_time_bin of this RegistryDataParams.  # noqa: E501
        :rtype: str
        """
        return self._nrows_per_time_bin

    @nrows_per_time_bin.setter
    def nrows_per_time_bin(self, nrows_per_time_bin):
        """Sets the nrows_per_time_bin of this RegistryDataParams.

        Number of rows of data per time bin to load and test in CT. If null, will load all rows.  # noqa: E501

        :param nrows_per_time_bin: The nrows_per_time_bin of this RegistryDataParams.  # noqa: E501
        :type: str
        """

        self._nrows_per_time_bin = nrows_per_time_bin

    @property
    def sample(self):
        """Gets the sample of this RegistryDataParams.  # noqa: E501

        Whether to sample rows in the data. Default is True.  # noqa: E501

        :return: The sample of this RegistryDataParams.  # noqa: E501
        :rtype: bool
        """
        return self._sample

    @sample.setter
    def sample(self, sample):
        """Sets the sample of this RegistryDataParams.

        Whether to sample rows in the data. Default is True.  # noqa: E501

        :param sample: The sample of this RegistryDataParams.  # noqa: E501
        :type: bool
        """

        self._sample = sample

    @property
    def categorical_features(self):
        """Gets the categorical_features of this RegistryDataParams.  # noqa: E501

        Feature types and relations.  # noqa: E501

        :return: The categorical_features of this RegistryDataParams.  # noqa: E501
        :rtype: list[str]
        """
        return self._categorical_features

    @categorical_features.setter
    def categorical_features(self, categorical_features):
        """Sets the categorical_features of this RegistryDataParams.

        Feature types and relations.  # noqa: E501

        :param categorical_features: The categorical_features of this RegistryDataParams.  # noqa: E501
        :type: list[str]
        """

        self._categorical_features = categorical_features

    @property
    def protected_features(self):
        """Gets the protected_features of this RegistryDataParams.  # noqa: E501

        Features that are protected attributes. If Bias and Fairness category is specified, these tests will run only over protected_features.  # noqa: E501

        :return: The protected_features of this RegistryDataParams.  # noqa: E501
        :rtype: list[str]
        """
        return self._protected_features

    @protected_features.setter
    def protected_features(self, protected_features):
        """Sets the protected_features of this RegistryDataParams.

        Features that are protected attributes. If Bias and Fairness category is specified, these tests will run only over protected_features.  # noqa: E501

        :param protected_features: The protected_features of this RegistryDataParams.  # noqa: E501
        :type: list[str]
        """

        self._protected_features = protected_features

    @property
    def features_not_in_model(self):
        """Gets the features_not_in_model of this RegistryDataParams.  # noqa: E501


        :return: The features_not_in_model of this RegistryDataParams.  # noqa: E501
        :rtype: list[str]
        """
        return self._features_not_in_model

    @features_not_in_model.setter
    def features_not_in_model(self, features_not_in_model):
        """Sets the features_not_in_model of this RegistryDataParams.


        :param features_not_in_model: The features_not_in_model of this RegistryDataParams.  # noqa: E501
        :type: list[str]
        """

        self._features_not_in_model = features_not_in_model

    @property
    def text_features(self):
        """Gets the text_features of this RegistryDataParams.  # noqa: E501

        Text features to run NLP tests over.  # noqa: E501

        :return: The text_features of this RegistryDataParams.  # noqa: E501
        :rtype: list[str]
        """
        return self._text_features

    @text_features.setter
    def text_features(self, text_features):
        """Sets the text_features of this RegistryDataParams.

        Text features to run NLP tests over.  # noqa: E501

        :param text_features: The text_features of this RegistryDataParams.  # noqa: E501
        :type: list[str]
        """

        self._text_features = text_features

    @property
    def image_features(self):
        """Gets the image_features of this RegistryDataParams.  # noqa: E501

        Image features to run CV tests over.  # noqa: E501

        :return: The image_features of this RegistryDataParams.  # noqa: E501
        :rtype: list[str]
        """
        return self._image_features

    @image_features.setter
    def image_features(self, image_features):
        """Sets the image_features of this RegistryDataParams.

        Image features to run CV tests over.  # noqa: E501

        :param image_features: The image_features of this RegistryDataParams.  # noqa: E501
        :type: list[str]
        """

        self._image_features = image_features

    @property
    def prompt_col(self):
        """Gets the prompt_col of this RegistryDataParams.  # noqa: E501

        Prompt template column for Generative tasks.  # noqa: E501

        :return: The prompt_col of this RegistryDataParams.  # noqa: E501
        :rtype: str
        """
        return self._prompt_col

    @prompt_col.setter
    def prompt_col(self, prompt_col):
        """Sets the prompt_col of this RegistryDataParams.

        Prompt template column for Generative tasks.  # noqa: E501

        :param prompt_col: The prompt_col of this RegistryDataParams.  # noqa: E501
        :type: str
        """

        self._prompt_col = prompt_col

    @property
    def intersections(self):
        """Gets the intersections of this RegistryDataParams.  # noqa: E501

        A list of arrays of features. Each array represents the intersection of features on which certain subset and fairness tests are run.  # noqa: E501

        :return: The intersections of this RegistryDataParams.  # noqa: E501
        :rtype: list[DataParamsFeatureIntersection]
        """
        return self._intersections

    @intersections.setter
    def intersections(self, intersections):
        """Sets the intersections of this RegistryDataParams.

        A list of arrays of features. Each array represents the intersection of features on which certain subset and fairness tests are run.  # noqa: E501

        :param intersections: The intersections of this RegistryDataParams.  # noqa: E501
        :type: list[DataParamsFeatureIntersection]
        """

        self._intersections = intersections

    @property
    def loading_kwargs(self):
        """Gets the loading_kwargs of this RegistryDataParams.  # noqa: E501

        Paths for external resources. Keyword arguments to be passed to the pandas loading function (either pd.read_CSV or pd.read_Parquet, depending on your data format). NOTE: if you wish to specify nrows, this should NOT be done with kwargs.  # noqa: E501

        :return: The loading_kwargs of this RegistryDataParams.  # noqa: E501
        :rtype: str
        """
        return self._loading_kwargs

    @loading_kwargs.setter
    def loading_kwargs(self, loading_kwargs):
        """Sets the loading_kwargs of this RegistryDataParams.

        Paths for external resources. Keyword arguments to be passed to the pandas loading function (either pd.read_CSV or pd.read_Parquet, depending on your data format). NOTE: if you wish to specify nrows, this should NOT be done with kwargs.  # noqa: E501

        :param loading_kwargs: The loading_kwargs of this RegistryDataParams.  # noqa: E501
        :type: str
        """

        self._loading_kwargs = loading_kwargs

    @property
    def feature_type_path(self):
        """Gets the feature_type_path of this RegistryDataParams.  # noqa: E501

        Path to a CSV file that specifies the data type of each feature. The file should have two columns: FeatureName and FeatureType.  # noqa: E501

        :return: The feature_type_path of this RegistryDataParams.  # noqa: E501
        :rtype: str
        """
        return self._feature_type_path

    @feature_type_path.setter
    def feature_type_path(self, feature_type_path):
        """Sets the feature_type_path of this RegistryDataParams.

        Path to a CSV file that specifies the data type of each feature. The file should have two columns: FeatureName and FeatureType.  # noqa: E501

        :param feature_type_path: The feature_type_path of this RegistryDataParams.  # noqa: E501
        :type: str
        """

        self._feature_type_path = feature_type_path

    @property
    def image_load_path(self):
        """Gets the image_load_path of this RegistryDataParams.  # noqa: E501

        Path to a python file containing a custom function for loading images in the dataset.  # noqa: E501

        :return: The image_load_path of this RegistryDataParams.  # noqa: E501
        :rtype: str
        """
        return self._image_load_path

    @image_load_path.setter
    def image_load_path(self, image_load_path):
        """Sets the image_load_path of this RegistryDataParams.

        Path to a python file containing a custom function for loading images in the dataset.  # noqa: E501

        :param image_load_path: The image_load_path of this RegistryDataParams.  # noqa: E501
        :type: str
        """

        self._image_load_path = image_load_path

    @property
    def experimental_fields(self):
        """Gets the experimental_fields of this RegistryDataParams.  # noqa: E501

        Fields that enable experimental functionality.  WARNING: these fields are experimental; ie, their functionality may not be reliable or backwards-compatible. Do not use these fields in production.  # noqa: E501

        :return: The experimental_fields of this RegistryDataParams.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._experimental_fields

    @experimental_fields.setter
    def experimental_fields(self, experimental_fields):
        """Sets the experimental_fields of this RegistryDataParams.

        Fields that enable experimental functionality.  WARNING: these fields are experimental; ie, their functionality may not be reliable or backwards-compatible. Do not use these fields in production.  # noqa: E501

        :param experimental_fields: The experimental_fields of this RegistryDataParams.  # noqa: E501
        :type: dict(str, object)
        """

        self._experimental_fields = experimental_fields

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RegistryDataParams, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RegistryDataParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RimeListDetectionEventsRequestQuery(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'firewall_id': 'RimeUUID',
        'event_object_id': 'str',
        'event_time_range': 'RimeTimeInterval',
        'severity': 'RimeSeverity',
        'event_types': 'list[DetectionEventType]',
        'risk_category_types': 'list[RiskscoreRiskCategoryType]',
        'test_categories': 'list[TestrunTestCategoryType]',
        'sort': 'RimeSortSpec'
    }

    attribute_map = {
        'firewall_id': 'firewallId',
        'event_object_id': 'eventObjectId',
        'event_time_range': 'eventTimeRange',
        'severity': 'severity',
        'event_types': 'eventTypes',
        'risk_category_types': 'riskCategoryTypes',
        'test_categories': 'testCategories',
        'sort': 'sort'
    }

    def __init__(self, firewall_id=None, event_object_id=None, event_time_range=None, severity=None, event_types=None, risk_category_types=None, test_categories=None, sort=None):  # noqa: E501
        """RimeListDetectionEventsRequestQuery - a model defined in Swagger"""  # noqa: E501
        self._firewall_id = None
        self._event_object_id = None
        self._event_time_range = None
        self._severity = None
        self._event_types = None
        self._risk_category_types = None
        self._test_categories = None
        self._sort = None
        self.discriminator = None
        if firewall_id is not None:
            self.firewall_id = firewall_id
        if event_object_id is not None:
            self.event_object_id = event_object_id
        if event_time_range is not None:
            self.event_time_range = event_time_range
        if severity is not None:
            self.severity = severity
        if event_types is not None:
            self.event_types = event_types
        if risk_category_types is not None:
            self.risk_category_types = risk_category_types
        if test_categories is not None:
            self.test_categories = test_categories
        if sort is not None:
            self.sort = sort

    @property
    def firewall_id(self):
        """Gets the firewall_id of this RimeListDetectionEventsRequestQuery.  # noqa: E501


        :return: The firewall_id of this RimeListDetectionEventsRequestQuery.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._firewall_id

    @firewall_id.setter
    def firewall_id(self, firewall_id):
        """Sets the firewall_id of this RimeListDetectionEventsRequestQuery.


        :param firewall_id: The firewall_id of this RimeListDetectionEventsRequestQuery.  # noqa: E501
        :type: RimeUUID
        """

        self._firewall_id = firewall_id

    @property
    def event_object_id(self):
        """Gets the event_object_id of this RimeListDetectionEventsRequestQuery.  # noqa: E501

        Optional: return a series of detection events for a single object.  # noqa: E501

        :return: The event_object_id of this RimeListDetectionEventsRequestQuery.  # noqa: E501
        :rtype: str
        """
        return self._event_object_id

    @event_object_id.setter
    def event_object_id(self, event_object_id):
        """Sets the event_object_id of this RimeListDetectionEventsRequestQuery.

        Optional: return a series of detection events for a single object.  # noqa: E501

        :param event_object_id: The event_object_id of this RimeListDetectionEventsRequestQuery.  # noqa: E501
        :type: str
        """

        self._event_object_id = event_object_id

    @property
    def event_time_range(self):
        """Gets the event_time_range of this RimeListDetectionEventsRequestQuery.  # noqa: E501


        :return: The event_time_range of this RimeListDetectionEventsRequestQuery.  # noqa: E501
        :rtype: RimeTimeInterval
        """
        return self._event_time_range

    @event_time_range.setter
    def event_time_range(self, event_time_range):
        """Sets the event_time_range of this RimeListDetectionEventsRequestQuery.


        :param event_time_range: The event_time_range of this RimeListDetectionEventsRequestQuery.  # noqa: E501
        :type: RimeTimeInterval
        """

        self._event_time_range = event_time_range

    @property
    def severity(self):
        """Gets the severity of this RimeListDetectionEventsRequestQuery.  # noqa: E501


        :return: The severity of this RimeListDetectionEventsRequestQuery.  # noqa: E501
        :rtype: RimeSeverity
        """
        return self._severity

    @severity.setter
    def severity(self, severity):
        """Sets the severity of this RimeListDetectionEventsRequestQuery.


        :param severity: The severity of this RimeListDetectionEventsRequestQuery.  # noqa: E501
        :type: RimeSeverity
        """

        self._severity = severity

    @property
    def event_types(self):
        """Gets the event_types of this RimeListDetectionEventsRequestQuery.  # noqa: E501

        Optional: When the list is empty, returns all.  # noqa: E501

        :return: The event_types of this RimeListDetectionEventsRequestQuery.  # noqa: E501
        :rtype: list[DetectionEventType]
        """
        return self._event_types

    @event_types.setter
    def event_types(self, event_types):
        """Sets the event_types of this RimeListDetectionEventsRequestQuery.

        Optional: When the list is empty, returns all.  # noqa: E501

        :param event_types: The event_types of this RimeListDetectionEventsRequestQuery.  # noqa: E501
        :type: list[DetectionEventType]
        """

        self._event_types = event_types

    @property
    def risk_category_types(self):
        """Gets the risk_category_types of this RimeListDetectionEventsRequestQuery.  # noqa: E501

        Optional: When the list is empty, returns all.  # noqa: E501

        :return: The risk_category_types of this RimeListDetectionEventsRequestQuery.  # noqa: E501
        :rtype: list[RiskscoreRiskCategoryType]
        """
        return self._risk_category_types

    @risk_category_types.setter
    def risk_category_types(self, risk_category_types):
        """Sets the risk_category_types of this RimeListDetectionEventsRequestQuery.

        Optional: When the list is empty, returns all.  # noqa: E501

        :param risk_category_types: The risk_category_types of this RimeListDetectionEventsRequestQuery.  # noqa: E501
        :type: list[RiskscoreRiskCategoryType]
        """

        self._risk_category_types = risk_category_types

    @property
    def test_categories(self):
        """Gets the test_categories of this RimeListDetectionEventsRequestQuery.  # noqa: E501

        Optional: When the list is empty, return all.  # noqa: E501

        :return: The test_categories of this RimeListDetectionEventsRequestQuery.  # noqa: E501
        :rtype: list[TestrunTestCategoryType]
        """
        return self._test_categories

    @test_categories.setter
    def test_categories(self, test_categories):
        """Sets the test_categories of this RimeListDetectionEventsRequestQuery.

        Optional: When the list is empty, return all.  # noqa: E501

        :param test_categories: The test_categories of this RimeListDetectionEventsRequestQuery.  # noqa: E501
        :type: list[TestrunTestCategoryType]
        """

        self._test_categories = test_categories

    @property
    def sort(self):
        """Gets the sort of this RimeListDetectionEventsRequestQuery.  # noqa: E501


        :return: The sort of this RimeListDetectionEventsRequestQuery.  # noqa: E501
        :rtype: RimeSortSpec
        """
        return self._sort

    @sort.setter
    def sort(self, sort):
        """Sets the sort of this RimeListDetectionEventsRequestQuery.


        :param sort: The sort of this RimeListDetectionEventsRequestQuery.  # noqa: E501
        :type: RimeSortSpec
        """

        self._sort = sort

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RimeListDetectionEventsRequestQuery, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RimeListDetectionEventsRequestQuery):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RegistryModelInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'model_path': 'RegistryModelPathInfo',
        'hugging_face': 'RegistryHuggingFaceModelInfo',
        'generative_language_model': 'RegistryGenerativeLanguageModelInfo'
    }

    attribute_map = {
        'model_path': 'modelPath',
        'hugging_face': 'huggingFace',
        'generative_language_model': 'generativeLanguageModel'
    }

    def __init__(self, model_path=None, hugging_face=None, generative_language_model=None):  # noqa: E501
        """RegistryModelInfo - a model defined in Swagger"""  # noqa: E501
        self._model_path = None
        self._hugging_face = None
        self._generative_language_model = None
        self.discriminator = None
        if model_path is not None:
            self.model_path = model_path
        if hugging_face is not None:
            self.hugging_face = hugging_face
        if generative_language_model is not None:
            self.generative_language_model = generative_language_model

    @property
    def model_path(self):
        """Gets the model_path of this RegistryModelInfo.  # noqa: E501


        :return: The model_path of this RegistryModelInfo.  # noqa: E501
        :rtype: RegistryModelPathInfo
        """
        return self._model_path

    @model_path.setter
    def model_path(self, model_path):
        """Sets the model_path of this RegistryModelInfo.


        :param model_path: The model_path of this RegistryModelInfo.  # noqa: E501
        :type: RegistryModelPathInfo
        """

        self._model_path = model_path

    @property
    def hugging_face(self):
        """Gets the hugging_face of this RegistryModelInfo.  # noqa: E501


        :return: The hugging_face of this RegistryModelInfo.  # noqa: E501
        :rtype: RegistryHuggingFaceModelInfo
        """
        return self._hugging_face

    @hugging_face.setter
    def hugging_face(self, hugging_face):
        """Sets the hugging_face of this RegistryModelInfo.


        :param hugging_face: The hugging_face of this RegistryModelInfo.  # noqa: E501
        :type: RegistryHuggingFaceModelInfo
        """

        self._hugging_face = hugging_face

    @property
    def generative_language_model(self):
        """Gets the generative_language_model of this RegistryModelInfo.  # noqa: E501


        :return: The generative_language_model of this RegistryModelInfo.  # noqa: E501
        :rtype: RegistryGenerativeLanguageModelInfo
        """
        return self._generative_language_model

    @generative_language_model.setter
    def generative_language_model(self, generative_language_model):
        """Sets the generative_language_model of this RegistryModelInfo.


        :param generative_language_model: The generative_language_model of this RegistryModelInfo.  # noqa: E501
        :type: RegistryGenerativeLanguageModelInfo
        """

        self._generative_language_model = generative_language_model

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RegistryModelInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RegistryModelInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RimeFeatureFlags(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'customer_name': 'str',
        'subscription_expiration_time': 'datetime',
        'num_projects': 'str',
        'num_test_runs': 'str',
        'upload_size_bytes': 'str',
        'enable_model_cards': 'bool',
        'num_firewalls': 'str'
    }

    attribute_map = {
        'customer_name': 'customerName',
        'subscription_expiration_time': 'subscriptionExpirationTime',
        'num_projects': 'numProjects',
        'num_test_runs': 'numTestRuns',
        'upload_size_bytes': 'uploadSizeBytes',
        'enable_model_cards': 'enableModelCards',
        'num_firewalls': 'numFirewalls'
    }

    def __init__(self, customer_name=None, subscription_expiration_time=None, num_projects=None, num_test_runs=None, upload_size_bytes=None, enable_model_cards=None, num_firewalls=None):  # noqa: E501
        """RimeFeatureFlags - a model defined in Swagger"""  # noqa: E501
        self._customer_name = None
        self._subscription_expiration_time = None
        self._num_projects = None
        self._num_test_runs = None
        self._upload_size_bytes = None
        self._enable_model_cards = None
        self._num_firewalls = None
        self.discriminator = None
        if customer_name is not None:
            self.customer_name = customer_name
        if subscription_expiration_time is not None:
            self.subscription_expiration_time = subscription_expiration_time
        if num_projects is not None:
            self.num_projects = num_projects
        if num_test_runs is not None:
            self.num_test_runs = num_test_runs
        if upload_size_bytes is not None:
            self.upload_size_bytes = upload_size_bytes
        if enable_model_cards is not None:
            self.enable_model_cards = enable_model_cards
        if num_firewalls is not None:
            self.num_firewalls = num_firewalls

    @property
    def customer_name(self):
        """Gets the customer_name of this RimeFeatureFlags.  # noqa: E501

        Customer Name. We maintain 1 set per customer. We need this for multi-tenancy (N customers in 1 cluster).  # noqa: E501

        :return: The customer_name of this RimeFeatureFlags.  # noqa: E501
        :rtype: str
        """
        return self._customer_name

    @customer_name.setter
    def customer_name(self, customer_name):
        """Sets the customer_name of this RimeFeatureFlags.

        Customer Name. We maintain 1 set per customer. We need this for multi-tenancy (N customers in 1 cluster).  # noqa: E501

        :param customer_name: The customer_name of this RimeFeatureFlags.  # noqa: E501
        :type: str
        """

        self._customer_name = customer_name

    @property
    def subscription_expiration_time(self):
        """Gets the subscription_expiration_time of this RimeFeatureFlags.  # noqa: E501

        Subscription time.  # noqa: E501

        :return: The subscription_expiration_time of this RimeFeatureFlags.  # noqa: E501
        :rtype: datetime
        """
        return self._subscription_expiration_time

    @subscription_expiration_time.setter
    def subscription_expiration_time(self, subscription_expiration_time):
        """Sets the subscription_expiration_time of this RimeFeatureFlags.

        Subscription time.  # noqa: E501

        :param subscription_expiration_time: The subscription_expiration_time of this RimeFeatureFlags.  # noqa: E501
        :type: datetime
        """

        self._subscription_expiration_time = subscription_expiration_time

    @property
    def num_projects(self):
        """Gets the num_projects of this RimeFeatureFlags.  # noqa: E501

        Num projects (not including deleted).  # noqa: E501

        :return: The num_projects of this RimeFeatureFlags.  # noqa: E501
        :rtype: str
        """
        return self._num_projects

    @num_projects.setter
    def num_projects(self, num_projects):
        """Sets the num_projects of this RimeFeatureFlags.

        Num projects (not including deleted).  # noqa: E501

        :param num_projects: The num_projects of this RimeFeatureFlags.  # noqa: E501
        :type: str
        """

        self._num_projects = num_projects

    @property
    def num_test_runs(self):
        """Gets the num_test_runs of this RimeFeatureFlags.  # noqa: E501

        Num test runs (successful only).  # noqa: E501

        :return: The num_test_runs of this RimeFeatureFlags.  # noqa: E501
        :rtype: str
        """
        return self._num_test_runs

    @num_test_runs.setter
    def num_test_runs(self, num_test_runs):
        """Sets the num_test_runs of this RimeFeatureFlags.

        Num test runs (successful only).  # noqa: E501

        :param num_test_runs: The num_test_runs of this RimeFeatureFlags.  # noqa: E501
        :type: str
        """

        self._num_test_runs = num_test_runs

    @property
    def upload_size_bytes(self):
        """Gets the upload_size_bytes of this RimeFeatureFlags.  # noqa: E501

        Upload data size.  # noqa: E501

        :return: The upload_size_bytes of this RimeFeatureFlags.  # noqa: E501
        :rtype: str
        """
        return self._upload_size_bytes

    @upload_size_bytes.setter
    def upload_size_bytes(self, upload_size_bytes):
        """Sets the upload_size_bytes of this RimeFeatureFlags.

        Upload data size.  # noqa: E501

        :param upload_size_bytes: The upload_size_bytes of this RimeFeatureFlags.  # noqa: E501
        :type: str
        """

        self._upload_size_bytes = upload_size_bytes

    @property
    def enable_model_cards(self):
        """Gets the enable_model_cards of this RimeFeatureFlags.  # noqa: E501

        Compliance model cards feature.  # noqa: E501

        :return: The enable_model_cards of this RimeFeatureFlags.  # noqa: E501
        :rtype: bool
        """
        return self._enable_model_cards

    @enable_model_cards.setter
    def enable_model_cards(self, enable_model_cards):
        """Sets the enable_model_cards of this RimeFeatureFlags.

        Compliance model cards feature.  # noqa: E501

        :param enable_model_cards: The enable_model_cards of this RimeFeatureFlags.  # noqa: E501
        :type: bool
        """

        self._enable_model_cards = enable_model_cards

    @property
    def num_firewalls(self):
        """Gets the num_firewalls of this RimeFeatureFlags.  # noqa: E501

        Number of firewalls allowed.  # noqa: E501

        :return: The num_firewalls of this RimeFeatureFlags.  # noqa: E501
        :rtype: str
        """
        return self._num_firewalls

    @num_firewalls.setter
    def num_firewalls(self, num_firewalls):
        """Sets the num_firewalls of this RimeFeatureFlags.

        Number of firewalls allowed.  # noqa: E501

        :param num_firewalls: The num_firewalls of this RimeFeatureFlags.  # noqa: E501
        :type: str
        """

        self._num_firewalls = num_firewalls

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RimeFeatureFlags, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RimeFeatureFlags):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RimeGetMonitorResultResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'monitor_id': 'RimeUUID',
        'monitor_name': 'str',
        'metric_name': 'str',
        'threshold': 'MonitorThreshold',
        'data_points': 'list[RimeMonitorDataPoint]',
        'description_html': 'str',
        'long_description_tabs': 'list[RimeLongDescriptionTab]'
    }

    attribute_map = {
        'monitor_id': 'monitorId',
        'monitor_name': 'monitorName',
        'metric_name': 'metricName',
        'threshold': 'threshold',
        'data_points': 'dataPoints',
        'description_html': 'descriptionHtml',
        'long_description_tabs': 'longDescriptionTabs'
    }

    def __init__(self, monitor_id=None, monitor_name=None, metric_name=None, threshold=None, data_points=None, description_html=None, long_description_tabs=None):  # noqa: E501
        """RimeGetMonitorResultResponse - a model defined in Swagger"""  # noqa: E501
        self._monitor_id = None
        self._monitor_name = None
        self._metric_name = None
        self._threshold = None
        self._data_points = None
        self._description_html = None
        self._long_description_tabs = None
        self.discriminator = None
        if monitor_id is not None:
            self.monitor_id = monitor_id
        if monitor_name is not None:
            self.monitor_name = monitor_name
        if metric_name is not None:
            self.metric_name = metric_name
        if threshold is not None:
            self.threshold = threshold
        if data_points is not None:
            self.data_points = data_points
        if description_html is not None:
            self.description_html = description_html
        if long_description_tabs is not None:
            self.long_description_tabs = long_description_tabs

    @property
    def monitor_id(self):
        """Gets the monitor_id of this RimeGetMonitorResultResponse.  # noqa: E501


        :return: The monitor_id of this RimeGetMonitorResultResponse.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._monitor_id

    @monitor_id.setter
    def monitor_id(self, monitor_id):
        """Sets the monitor_id of this RimeGetMonitorResultResponse.


        :param monitor_id: The monitor_id of this RimeGetMonitorResultResponse.  # noqa: E501
        :type: RimeUUID
        """

        self._monitor_id = monitor_id

    @property
    def monitor_name(self):
        """Gets the monitor_name of this RimeGetMonitorResultResponse.  # noqa: E501

        The name of the monitor.  # noqa: E501

        :return: The monitor_name of this RimeGetMonitorResultResponse.  # noqa: E501
        :rtype: str
        """
        return self._monitor_name

    @monitor_name.setter
    def monitor_name(self, monitor_name):
        """Sets the monitor_name of this RimeGetMonitorResultResponse.

        The name of the monitor.  # noqa: E501

        :param monitor_name: The monitor_name of this RimeGetMonitorResultResponse.  # noqa: E501
        :type: str
        """

        self._monitor_name = monitor_name

    @property
    def metric_name(self):
        """Gets the metric_name of this RimeGetMonitorResultResponse.  # noqa: E501


        :return: The metric_name of this RimeGetMonitorResultResponse.  # noqa: E501
        :rtype: str
        """
        return self._metric_name

    @metric_name.setter
    def metric_name(self, metric_name):
        """Sets the metric_name of this RimeGetMonitorResultResponse.


        :param metric_name: The metric_name of this RimeGetMonitorResultResponse.  # noqa: E501
        :type: str
        """

        self._metric_name = metric_name

    @property
    def threshold(self):
        """Gets the threshold of this RimeGetMonitorResultResponse.  # noqa: E501


        :return: The threshold of this RimeGetMonitorResultResponse.  # noqa: E501
        :rtype: MonitorThreshold
        """
        return self._threshold

    @threshold.setter
    def threshold(self, threshold):
        """Sets the threshold of this RimeGetMonitorResultResponse.


        :param threshold: The threshold of this RimeGetMonitorResultResponse.  # noqa: E501
        :type: MonitorThreshold
        """

        self._threshold = threshold

    @property
    def data_points(self):
        """Gets the data_points of this RimeGetMonitorResultResponse.  # noqa: E501

        The monitor data points.  # noqa: E501

        :return: The data_points of this RimeGetMonitorResultResponse.  # noqa: E501
        :rtype: list[RimeMonitorDataPoint]
        """
        return self._data_points

    @data_points.setter
    def data_points(self, data_points):
        """Sets the data_points of this RimeGetMonitorResultResponse.

        The monitor data points.  # noqa: E501

        :param data_points: The data_points of this RimeGetMonitorResultResponse.  # noqa: E501
        :type: list[RimeMonitorDataPoint]
        """

        self._data_points = data_points

    @property
    def description_html(self):
        """Gets the description_html of this RimeGetMonitorResultResponse.  # noqa: E501

        Description of the monitor that may contain HTML.  # noqa: E501

        :return: The description_html of this RimeGetMonitorResultResponse.  # noqa: E501
        :rtype: str
        """
        return self._description_html

    @description_html.setter
    def description_html(self, description_html):
        """Sets the description_html of this RimeGetMonitorResultResponse.

        Description of the monitor that may contain HTML.  # noqa: E501

        :param description_html: The description_html of this RimeGetMonitorResultResponse.  # noqa: E501
        :type: str
        """

        self._description_html = description_html

    @property
    def long_description_tabs(self):
        """Gets the long_description_tabs of this RimeGetMonitorResultResponse.  # noqa: E501

        More detailed information about the monitor.  # noqa: E501

        :return: The long_description_tabs of this RimeGetMonitorResultResponse.  # noqa: E501
        :rtype: list[RimeLongDescriptionTab]
        """
        return self._long_description_tabs

    @long_description_tabs.setter
    def long_description_tabs(self, long_description_tabs):
        """Sets the long_description_tabs of this RimeGetMonitorResultResponse.

        More detailed information about the monitor.  # noqa: E501

        :param long_description_tabs: The long_description_tabs of this RimeGetMonitorResultResponse.  # noqa: E501
        :type: list[RimeLongDescriptionTab]
        """

        self._long_description_tabs = long_description_tabs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RimeGetMonitorResultResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RimeGetMonitorResultResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TestrunDataProfiling(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'num_quantiles': 'str',
        'num_subsets': 'str',
        'column_type_info': 'DataProfilingColumnTypeInfo',
        'feature_relationship_info': 'DataProfilingFeatureRelationshipInfo'
    }

    attribute_map = {
        'num_quantiles': 'numQuantiles',
        'num_subsets': 'numSubsets',
        'column_type_info': 'columnTypeInfo',
        'feature_relationship_info': 'featureRelationshipInfo'
    }

    def __init__(self, num_quantiles=None, num_subsets=None, column_type_info=None, feature_relationship_info=None):  # noqa: E501
        """TestrunDataProfiling - a model defined in Swagger"""  # noqa: E501
        self._num_quantiles = None
        self._num_subsets = None
        self._column_type_info = None
        self._feature_relationship_info = None
        self.discriminator = None
        if num_quantiles is not None:
            self.num_quantiles = num_quantiles
        if num_subsets is not None:
            self.num_subsets = num_subsets
        if column_type_info is not None:
            self.column_type_info = column_type_info
        if feature_relationship_info is not None:
            self.feature_relationship_info = feature_relationship_info

    @property
    def num_quantiles(self):
        """Gets the num_quantiles of this TestrunDataProfiling.  # noqa: E501

        The number of quantiles to split numeric subsets into.  # noqa: E501

        :return: The num_quantiles of this TestrunDataProfiling.  # noqa: E501
        :rtype: str
        """
        return self._num_quantiles

    @num_quantiles.setter
    def num_quantiles(self, num_quantiles):
        """Sets the num_quantiles of this TestrunDataProfiling.

        The number of quantiles to split numeric subsets into.  # noqa: E501

        :param num_quantiles: The num_quantiles of this TestrunDataProfiling.  # noqa: E501
        :type: str
        """

        self._num_quantiles = num_quantiles

    @property
    def num_subsets(self):
        """Gets the num_subsets of this TestrunDataProfiling.  # noqa: E501

        The number of subsets to test. This field is sorted by count.  # noqa: E501

        :return: The num_subsets of this TestrunDataProfiling.  # noqa: E501
        :rtype: str
        """
        return self._num_subsets

    @num_subsets.setter
    def num_subsets(self, num_subsets):
        """Sets the num_subsets of this TestrunDataProfiling.

        The number of subsets to test. This field is sorted by count.  # noqa: E501

        :param num_subsets: The num_subsets of this TestrunDataProfiling.  # noqa: E501
        :type: str
        """

        self._num_subsets = num_subsets

    @property
    def column_type_info(self):
        """Gets the column_type_info of this TestrunDataProfiling.  # noqa: E501


        :return: The column_type_info of this TestrunDataProfiling.  # noqa: E501
        :rtype: DataProfilingColumnTypeInfo
        """
        return self._column_type_info

    @column_type_info.setter
    def column_type_info(self, column_type_info):
        """Sets the column_type_info of this TestrunDataProfiling.


        :param column_type_info: The column_type_info of this TestrunDataProfiling.  # noqa: E501
        :type: DataProfilingColumnTypeInfo
        """

        self._column_type_info = column_type_info

    @property
    def feature_relationship_info(self):
        """Gets the feature_relationship_info of this TestrunDataProfiling.  # noqa: E501


        :return: The feature_relationship_info of this TestrunDataProfiling.  # noqa: E501
        :rtype: DataProfilingFeatureRelationshipInfo
        """
        return self._feature_relationship_info

    @feature_relationship_info.setter
    def feature_relationship_info(self, feature_relationship_info):
        """Sets the feature_relationship_info of this TestrunDataProfiling.


        :param feature_relationship_info: The feature_relationship_info of this TestrunDataProfiling.  # noqa: E501
        :type: DataProfilingFeatureRelationshipInfo
        """

        self._feature_relationship_info = feature_relationship_info

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TestrunDataProfiling, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TestrunDataProfiling):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RimeSeverityCounts(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'num_none_severity': 'str',
        'num_low_severity': 'str',
        'num_high_severity': 'str'
    }

    attribute_map = {
        'num_none_severity': 'numNoneSeverity',
        'num_low_severity': 'numLowSeverity',
        'num_high_severity': 'numHighSeverity'
    }

    def __init__(self, num_none_severity=None, num_low_severity=None, num_high_severity=None):  # noqa: E501
        """RimeSeverityCounts - a model defined in Swagger"""  # noqa: E501
        self._num_none_severity = None
        self._num_low_severity = None
        self._num_high_severity = None
        self.discriminator = None
        if num_none_severity is not None:
            self.num_none_severity = num_none_severity
        if num_low_severity is not None:
            self.num_low_severity = num_low_severity
        if num_high_severity is not None:
            self.num_high_severity = num_high_severity

    @property
    def num_none_severity(self):
        """Gets the num_none_severity of this RimeSeverityCounts.  # noqa: E501


        :return: The num_none_severity of this RimeSeverityCounts.  # noqa: E501
        :rtype: str
        """
        return self._num_none_severity

    @num_none_severity.setter
    def num_none_severity(self, num_none_severity):
        """Sets the num_none_severity of this RimeSeverityCounts.


        :param num_none_severity: The num_none_severity of this RimeSeverityCounts.  # noqa: E501
        :type: str
        """

        self._num_none_severity = num_none_severity

    @property
    def num_low_severity(self):
        """Gets the num_low_severity of this RimeSeverityCounts.  # noqa: E501


        :return: The num_low_severity of this RimeSeverityCounts.  # noqa: E501
        :rtype: str
        """
        return self._num_low_severity

    @num_low_severity.setter
    def num_low_severity(self, num_low_severity):
        """Sets the num_low_severity of this RimeSeverityCounts.


        :param num_low_severity: The num_low_severity of this RimeSeverityCounts.  # noqa: E501
        :type: str
        """

        self._num_low_severity = num_low_severity

    @property
    def num_high_severity(self):
        """Gets the num_high_severity of this RimeSeverityCounts.  # noqa: E501


        :return: The num_high_severity of this RimeSeverityCounts.  # noqa: E501
        :rtype: str
        """
        return self._num_high_severity

    @num_high_severity.setter
    def num_high_severity(self, num_high_severity):
        """Sets the num_high_severity of this RimeSeverityCounts.


        :param num_high_severity: The num_high_severity of this RimeSeverityCounts.  # noqa: E501
        :type: str
        """

        self._num_high_severity = num_high_severity

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RimeSeverityCounts, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RimeSeverityCounts):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



"""Python package providing access to Robust Intelligence.

The RIME SDK provides a programmatic interface to a Robust Intelligence
instance, allowing you to create projects, start stress tests, query the
backend for test run results, and more from within your Python code. To
begin, initialize a client, which acts as the main entry point to SDK
functions.

"""
from rime_sdk.client import (
    Client,
    ManagedImagePackageRequirement,
    ManagedImagePipRequirement,
)
from rime_sdk.data_collector import DataCollector
from rime_sdk.detection_event import DetectionEvent
from rime_sdk.firewall import Firewall
from rime_sdk.image_builder import ImageBuilder
from rime_sdk.job import ContinuousTestJob, Job
from rime_sdk.monitor import Monitor
from rime_sdk.project import Project
from rime_sdk.registry import Registry
from rime_sdk.swagger.swagger_client.models import RuntimeinfoCustomImage as CustomImage
from rime_sdk.test_batch import TestBatch
from rime_sdk.test_run import ContinuousTestRun, TestRun

__all__ = [
    "Client",
    "ManagedImagePackageRequirement",
    "ManagedImagePipRequirement",
    "Project",
    "Job",
    "ContinuousTestJob",
    "TestRun",
    "ContinuousTestRun",
    "TestBatch",
    "Firewall",
    "ImageBuilder",
    "CustomImage",
    "DataCollector",
    "Registry",
    "DetectionEvent",
    "Monitor",
]



"""Shared types/logic for the data-specific checkers."""
from abc import abstractmethod
from pathlib import Path
from typing import Any, List


class DataFormatChecker:
    """Base class for the data-specific checkers."""

    success_msg = "\nYour data should work with RIME!\n"
    accepted_file_types: List[str]

    def check_file_format(self, file_path: Path) -> None:
        """Verify that the file at file_path is one of the accepted_file_types."""
        file_type = "".join(file_path.suffixes)
        if file_type not in self.accepted_file_types:
            raise ValueError(
                "Invalid file format: '{}'. Input must be one of the "
                "following: {}".format(file_path, self.accepted_file_types)
            )

    @abstractmethod
    def check(self, ref_path: Path, eval_path: Path, task: str, **kwargs: Any) -> None:
        """Perform all checks necessary to validate given file(s).

        Main entry point.
        """



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TestrunCustomMetric(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'file_path': 'str',
        'range_lower_bound': 'float',
        'range_upper_bound': 'float',
        'run_subset_performance': 'bool',
        'run_subset_performance_drift': 'bool',
        'run_overall_performance': 'bool',
        'metadata': 'CustomMetricCustomMetricMetadata'
    }

    attribute_map = {
        'name': 'name',
        'file_path': 'filePath',
        'range_lower_bound': 'rangeLowerBound',
        'range_upper_bound': 'rangeUpperBound',
        'run_subset_performance': 'runSubsetPerformance',
        'run_subset_performance_drift': 'runSubsetPerformanceDrift',
        'run_overall_performance': 'runOverallPerformance',
        'metadata': 'metadata'
    }

    def __init__(self, name=None, file_path=None, range_lower_bound=None, range_upper_bound=None, run_subset_performance=None, run_subset_performance_drift=None, run_overall_performance=None, metadata=None):  # noqa: E501
        """TestrunCustomMetric - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._file_path = None
        self._range_lower_bound = None
        self._range_upper_bound = None
        self._run_subset_performance = None
        self._run_subset_performance_drift = None
        self._run_overall_performance = None
        self._metadata = None
        self.discriminator = None
        self.name = name
        self.file_path = file_path
        if range_lower_bound is not None:
            self.range_lower_bound = range_lower_bound
        if range_upper_bound is not None:
            self.range_upper_bound = range_upper_bound
        if run_subset_performance is not None:
            self.run_subset_performance = run_subset_performance
        if run_subset_performance_drift is not None:
            self.run_subset_performance_drift = run_subset_performance_drift
        if run_overall_performance is not None:
            self.run_overall_performance = run_overall_performance
        if metadata is not None:
            self.metadata = metadata

    @property
    def name(self):
        """Gets the name of this TestrunCustomMetric.  # noqa: E501

        Name of the custom metric.  # noqa: E501

        :return: The name of this TestrunCustomMetric.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TestrunCustomMetric.

        Name of the custom metric.  # noqa: E501

        :param name: The name of this TestrunCustomMetric.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def file_path(self):
        """Gets the file_path of this TestrunCustomMetric.  # noqa: E501

        Path to the file with metric definition.  # noqa: E501

        :return: The file_path of this TestrunCustomMetric.  # noqa: E501
        :rtype: str
        """
        return self._file_path

    @file_path.setter
    def file_path(self, file_path):
        """Sets the file_path of this TestrunCustomMetric.

        Path to the file with metric definition.  # noqa: E501

        :param file_path: The file_path of this TestrunCustomMetric.  # noqa: E501
        :type: str
        """
        if file_path is None:
            raise ValueError("Invalid value for `file_path`, must not be `None`")  # noqa: E501

        self._file_path = file_path

    @property
    def range_lower_bound(self):
        """Gets the range_lower_bound of this TestrunCustomMetric.  # noqa: E501

        Valid range lower bound.  # noqa: E501

        :return: The range_lower_bound of this TestrunCustomMetric.  # noqa: E501
        :rtype: float
        """
        return self._range_lower_bound

    @range_lower_bound.setter
    def range_lower_bound(self, range_lower_bound):
        """Sets the range_lower_bound of this TestrunCustomMetric.

        Valid range lower bound.  # noqa: E501

        :param range_lower_bound: The range_lower_bound of this TestrunCustomMetric.  # noqa: E501
        :type: float
        """

        self._range_lower_bound = range_lower_bound

    @property
    def range_upper_bound(self):
        """Gets the range_upper_bound of this TestrunCustomMetric.  # noqa: E501

        Valid range upper bound.  # noqa: E501

        :return: The range_upper_bound of this TestrunCustomMetric.  # noqa: E501
        :rtype: float
        """
        return self._range_upper_bound

    @range_upper_bound.setter
    def range_upper_bound(self, range_upper_bound):
        """Sets the range_upper_bound of this TestrunCustomMetric.

        Valid range upper bound.  # noqa: E501

        :param range_upper_bound: The range_upper_bound of this TestrunCustomMetric.  # noqa: E501
        :type: float
        """

        self._range_upper_bound = range_upper_bound

    @property
    def run_subset_performance(self):
        """Gets the run_subset_performance of this TestrunCustomMetric.  # noqa: E501

        Should run subset performance.  # noqa: E501

        :return: The run_subset_performance of this TestrunCustomMetric.  # noqa: E501
        :rtype: bool
        """
        return self._run_subset_performance

    @run_subset_performance.setter
    def run_subset_performance(self, run_subset_performance):
        """Sets the run_subset_performance of this TestrunCustomMetric.

        Should run subset performance.  # noqa: E501

        :param run_subset_performance: The run_subset_performance of this TestrunCustomMetric.  # noqa: E501
        :type: bool
        """

        self._run_subset_performance = run_subset_performance

    @property
    def run_subset_performance_drift(self):
        """Gets the run_subset_performance_drift of this TestrunCustomMetric.  # noqa: E501

        Should run subset performance drift.  # noqa: E501

        :return: The run_subset_performance_drift of this TestrunCustomMetric.  # noqa: E501
        :rtype: bool
        """
        return self._run_subset_performance_drift

    @run_subset_performance_drift.setter
    def run_subset_performance_drift(self, run_subset_performance_drift):
        """Sets the run_subset_performance_drift of this TestrunCustomMetric.

        Should run subset performance drift.  # noqa: E501

        :param run_subset_performance_drift: The run_subset_performance_drift of this TestrunCustomMetric.  # noqa: E501
        :type: bool
        """

        self._run_subset_performance_drift = run_subset_performance_drift

    @property
    def run_overall_performance(self):
        """Gets the run_overall_performance of this TestrunCustomMetric.  # noqa: E501

        Should run overall performance.  # noqa: E501

        :return: The run_overall_performance of this TestrunCustomMetric.  # noqa: E501
        :rtype: bool
        """
        return self._run_overall_performance

    @run_overall_performance.setter
    def run_overall_performance(self, run_overall_performance):
        """Sets the run_overall_performance of this TestrunCustomMetric.

        Should run overall performance.  # noqa: E501

        :param run_overall_performance: The run_overall_performance of this TestrunCustomMetric.  # noqa: E501
        :type: bool
        """

        self._run_overall_performance = run_overall_performance

    @property
    def metadata(self):
        """Gets the metadata of this TestrunCustomMetric.  # noqa: E501


        :return: The metadata of this TestrunCustomMetric.  # noqa: E501
        :rtype: CustomMetricCustomMetricMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this TestrunCustomMetric.


        :param metadata: The metadata of this TestrunCustomMetric.  # noqa: E501
        :type: CustomMetricCustomMetricMetadata
        """

        self._metadata = metadata

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TestrunCustomMetric, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TestrunCustomMetric):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ValidateRequestOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'output_text': 'str'
    }

    attribute_map = {
        'output_text': 'outputText'
    }

    def __init__(self, output_text=None):  # noqa: E501
        """ValidateRequestOutput - a model defined in Swagger"""  # noqa: E501
        self._output_text = None
        self.discriminator = None
        if output_text is not None:
            self.output_text = output_text

    @property
    def output_text(self):
        """Gets the output_text of this ValidateRequestOutput.  # noqa: E501

        Output text is the raw output text of the model. The generative firewall performs validation on the output so the system can determine whether to show it to users.  # noqa: E501

        :return: The output_text of this ValidateRequestOutput.  # noqa: E501
        :rtype: str
        """
        return self._output_text

    @output_text.setter
    def output_text(self, output_text):
        """Sets the output_text of this ValidateRequestOutput.

        Output text is the raw output text of the model. The generative firewall performs validation on the output so the system can determine whether to show it to users.  # noqa: E501

        :param output_text: The output_text of this ValidateRequestOutput.  # noqa: E501
        :type: str
        """

        self._output_text = output_text

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ValidateRequestOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ValidateRequestOutput):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
